@@ -3,10 +3,9 @@ import logging
 import re
 from constants import *
 
+# http://code.google.com/p/python-nameparser/issues/detail?id=10
 log = logging.getLogger('HumanName')
-log.addHandler(logging.StreamHandler())
-# there are no log.error() calls, so this should essentially be 'off'.
-# have a better solution? please comment on http://code.google.com/p/python-nameparser/issues/detail?id=10
+log.addHandler(logging.NullHandler())
 log.setLevel(logging.ERROR)
 
 ENCODING = 'utf-8'
@@ -21,6 +20,7 @@ def is_an_initial(value):
     return re_initial.match(value) or False
 
 class BlankHumanNameError(AttributeError):
+    # deprecated in v0.2.5, no longer used
     pass
 
 class HumanName(object):
@@ -36,8 +36,8 @@ class HumanName(object):
      
     """
     
-    def __init__(self, full_name=u"", titles_c=TITLES, prefixes_c=PREFICES, 
-        suffixes_c=SUFFICES, punc_titles_c=PUNC_TITLES, conjunctions_c=CONJUNCTIONS,
+    def __init__(self, full_name=u"", titles_c=TITLES, prefixes_c=PREFIXES, 
+        suffixes_c=SUFFIXES, punc_titles_c=PUNC_TITLES, conjunctions_c=CONJUNCTIONS,
         capitalization_exceptions_c=dict(CAPITALIZATION_EXCEPTIONS), encoding=ENCODING,
         string_format=None):
         
@@ -261,8 +261,6 @@ class HumanName(object):
         """
         Parse full name into the buckets
         """
-        if not self._full_name:
-            raise BlankHumanNameError("Missing full_name")
         
         if not isinstance(self._full_name, unicode):
             self._full_name = unicode(self._full_name, self.ENCODING)
@@ -291,6 +289,7 @@ class HumanName(object):
                 except IndexError:
                     next = None
                 
+                # title must have a next piece, unless it's just a title
                 if self.is_title(piece) and (next or len(pieces) == 1):
                     self.title_list.append(piece)
                     continue
